@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2004, 2011-2012, 2017  Samuel Thibault <samuel.thibault@ens-lyon.org>
+ *  Copyright (C) 2004, 2011-2012, 2017, 2020  Samuel Thibault <samuel.thibault@ens-lyon.org>
  *
  * This program is free software ; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -222,7 +222,7 @@ int fxt_fdevents_stop(fxt_t fxt, int fd)
 	return 0;
 }
 
-int fxt_setupeventsbuffer(fxt_t fxt, struct fxt_evbuf *buffer, long size, int kind)
+int fxt_setupeventsbuffer(fxt_t fxt, struct fxt_evbuf *buffer, size_t size, int kind)
 {
 	struct fxt_block_ondisk* buf=(struct fxt_block_ondisk*)buffer;
 	if (sizeof(struct fxt_evbuf) != sizeof(struct fxt_block_ondisk)) {
